from operations import add_numbers, subtract_numbers, multiply_numbers, divide_numbers


# def add_numbers(num1, num2):
# 	return num1 + num2

# def subtract_numbers(num1, num2):
# 	return num1 - num2

# def multiply_numbers(num1, num2):
# 	return num1 * num2

# def divide_numbers(num1, num2):
# 	return num1 / num2

